@@ -232,10 +232,10 @@ typedef BOOL (WINAPI *pALLOW)(DWORD);
 
     /* check for patched content of pass_par_clean */
     {
-        char *equal = strchr(pass_par_clean, '=');
-        if (equal != NULL) {
-            equal[2] = '\0';    /* trim value to one byte */
-            par_setenv("PAR_CLEAN", equal + 1);
+        char *equals = strchr(pass_par_clean, '=');
+        if (equals != NULL) {
+            equals[2] = '\0';    /* trim value to one byte */
+            par_setenv("PAR_CLEAN", equals + 1);
         }
     }
 
